@@ -4,7 +4,7 @@
 
     gmp3info.c - main part of GTK version of MP3Info
 
-    Copyright (C) 2000-2001  Cedric Tefft <cedric@earthling.net>
+    Copyright (C) 2000-2006 Cedric Tefft <cedric@phreaker.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -79,8 +79,9 @@ void exit_save( GtkWidget *widget, GtkWidget *data) {
 	        mp3.id3.genre[0]=gget_genre(tmp);
 	   	strcpy(tmp,gtk_entry_get_text(GTK_ENTRY(id3win_text_track)));
 		mp3.id3.track[0]=atoi(tmp);
-		if (mp3.id3.track[0] > 255)
+/*		if (mp3.id3.track[0] > 255)
 			mp3.id3.track[0]=255;
+*/
 	        write_tag(&mp3);
 	   }
 
@@ -99,7 +100,7 @@ int main(int argc, char *argv[] ) {
 
 
         
-        id3win=gtk_window_new(GTK_WINDOW_DIALOG);
+        id3win=gtk_window_new(GTK_WINDOW_TOPLEVEL);
         gtk_window_set_title(GTK_WINDOW(id3win),"MP3info - An ID3 tag editor");
         gtk_window_set_policy (GTK_WINDOW(id3win), FALSE,FALSE,FALSE);
         gtk_widget_set_usize(id3win,450,360);
@@ -299,7 +300,7 @@ void create_techinfo_win(void) {
 	GtkWidget	*infowin_text_padding, *infowin_text_length;
 	GtkWidget	*infowin_text_frequency;
 	int		ibuf,ibuf2;
-	char		buf[50];
+	char		buf[1023];
 	char 		*layer_text[] = { "I", "II", "III" };
 
 
@@ -401,7 +402,7 @@ void open_mp3_file(void) {
 void read_new_mp3(GtkWidget *button, GtkWidget *file) {
 	char *filename;
 
-	filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(file));
+	filename = (char *)gtk_file_selection_get_filename(GTK_FILE_SELECTION(file));
 	if (load_mp3(filename) == 1) {
 		gtk_widget_destroy(file);
 		gtk_entry_set_text(GTK_ENTRY(id3win_text_title),mp3.id3.title);
@@ -409,7 +410,7 @@ void read_new_mp3(GtkWidget *button, GtkWidget *file) {
         	gtk_entry_set_text(GTK_ENTRY(id3win_text_album),mp3.id3.album);
         	gtk_entry_set_text(GTK_ENTRY(id3win_text_year),mp3.id3.year);
         	gtk_entry_set_text(GTK_ENTRY(id3win_text_comment),mp3.id3.comment);
-        	gtk_entry_set_text(GTK_ENTRY(id3win_text_track),mp3.id3.track);
+        	gtk_entry_set_text(GTK_ENTRY(id3win_text_track),(char *)mp3.id3.track);
         	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(id3win_combo_genre)->entry), gtext_genre(mp3.id3.genre[0]));
 	}
 
@@ -417,7 +418,7 @@ void read_new_mp3(GtkWidget *button, GtkWidget *file) {
 
 int load_mp3(char *filename) {
 
-mp3info nmp3;
+	mp3info nmp3;
 
 	memset(&nmp3,0,sizeof(mp3info));
 	
@@ -463,14 +464,17 @@ int kill_if_esc(GtkWidget *widget, GdkEventKey *event, gpointer obj) {
 
 void quick_popup(char *title, char *message) {
 	GtkWidget *popupwin, *popupwin_main, *popupwin_msg, *popupwin_ok;
+	char *markup;
 
 	popupwin = gtk_dialog_new();
 	gtk_widget_realize(popupwin);
 	gtk_container_border_width(GTK_CONTAINER(popupwin), 12);
 	gtk_window_set_title(GTK_WINDOW(popupwin), title);
 	popupwin_main = GTK_DIALOG(popupwin)->vbox;
-        gtk_container_add(GTK_CONTAINER(popupwin),popupwin_main);
-	popupwin_msg=gtk_label_new(message);
+	popupwin_msg=gtk_label_new(NULL);
+	markup = g_markup_printf_escaped("<span foreground=\"blue\">%s</span>",message);
+	gtk_label_set_markup(GTK_LABEL(popupwin_msg),markup);
+	g_free (markup);
 	gtk_box_pack_start(GTK_BOX(popupwin_main),popupwin_msg,TRUE,TRUE,0);
 	popupwin_ok = gtk_button_new_with_label(" OK ");
 	gtk_signal_connect_object(GTK_OBJECT(popupwin_ok), "clicked",
@@ -484,12 +488,11 @@ void quick_popup(char *title, char *message) {
 }
 
 void about_mp3info(void) {
-	quick_popup(VERSION,"MP3Info
-			An ID3 Tag Editor\n\n
-			Original author: Ricardo Cerqueira <rmc@plug.pt>
-			Current maintainer: Cedric Tefft <cedric@earthling.net>
-			GTK Version: Ricardo Cerqueira <rmc@plug.pt>\n\n
-			Ricardo Cerqueira, Cedric Tefft   1999-2001\n\n");
+	quick_popup(VERSION,"MP3Info\n"
+	"			An ID3 Tag Editor\n\n\n"
+	"			Original author: Ricardo Cerqueira <rmc@plug.pt>\n"
+	"			Current maintainer: Cedric Tefft <cedric@phreaker.net>\n"
+	"			(C) 1999-2006 Ricardo Cerqueira, Cedric Tefft\n\n");
 }
 
 /* rmcc has left the building */
