@@ -1,7 +1,7 @@
 /*
     mp3info.h - Header files for MP3Info
 
-    Copyright (C) 2000-2001  Cedric Tefft <cedric@earthling.net>
+    Copyright (C) 2000-2006 Cedric Tefft <cedric@phreaker.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,17 +29,23 @@
 #include <sys/stat.h>
 #include <ctype.h>
 #include <string.h>
-#include <curses.h>
-#include <signal.h>
-#ifdef __CYGWIN32__
+#ifdef __WIN32__
+#include "win32/curses.h"
+#define uint unsigned int
 #include <getopt.h>
+#ifdef __MINGW32__
+int truncate(const char *name, off_t length);
 #endif
+#else
+#include <curses.h>
+#endif
+#include <signal.h>
 #include "mp3tech.h"
 #include "textfunc.h"
 
 
-#define VERSION "MP3Info 0.8.4"
-#define COPYRIGHT "Copyright (C) 2001 Cedric Tefft and Ricardo Cerqueira"
+#define VERSION "MP3Info 0.8.5a"
+#define COPYRIGHT "Copyright (C) 2006 Cedric Tefft and Ricardo Cerqueira"
 #define MAXGENRE   147
 #define GENREROWS  50
 
@@ -94,6 +100,11 @@ int galphagenreindex[MAXGENRE+2] = {
 
 int *alphagenreindex=&(galphagenreindex[1]);          
 
+#ifdef __WIN32__
+	extern int	opterr,optind,optopt,optreset;
+	extern char	*optarg;
+#endif
+
 #else
 	extern char *typegenre [MAXGENRE+2];
 	extern int alphagenreindex [MAXGENRE+1];
